@@ -134,7 +134,7 @@ pub mod rand {
 #[cfg(not(feature = "log-rs"))]
 /// Logging macros, available with miniquad "log-impl" feature.
 pub mod logging {
-    pub use miniquad::{debug, error, info, warn};
+    pub use miniquad::{debug, error, info, trace, warn};
 }
 #[cfg(feature = "log-rs")]
 // Use logging facade
@@ -299,7 +299,7 @@ impl Context {
             camera_matrix: None,
             gl: QuadGl::new(&mut ctx),
 
-            ui_context: UiContext::new(&mut ctx),
+            ui_context: UiContext::new(&mut ctx, screen_width, screen_height),
             fonts_storage: text::FontsStorage::new(&mut ctx),
             texture_batcher: texture::Batcher::new(&mut ctx),
             camera_stack: vec![],
