@@ -106,7 +106,6 @@ impl From<crate::texture::Texture2D> for UiContent<'static> {
 pub(crate) struct Window {
     pub id: Id,
     pub parent: Option<Id>,
-    pub visible: bool,
     // active is set to true when the begin_window is called on this window
     // and is going to be set to false at the end of each frame
     pub active: bool,
@@ -123,6 +122,9 @@ pub(crate) struct Window {
     pub childs: Vec<Id>,
     pub want_close: bool,
     pub force_focus: bool,
+
+    margin: f32,
+    window_margin: RectOffset,
 }
 
 impl Window {
@@ -145,7 +147,6 @@ impl Window {
             vertical_scroll_bar_width: 0.,
             title_height,
             parent,
-            visible: true,
             was_active: false,
             active: false,
             painter: Painter::new(atlas),
@@ -158,6 +159,8 @@ impl Window {
                 ),
                 margin,
             ),
+            margin,
+            window_margin,
             childs: vec![],
             want_close: false,
             movable,
@@ -165,6 +168,22 @@ impl Window {
         }
     }
 
+    pub fn resize(&mut self, size: Vec2) {
+        self.size = size;
+        self.cursor = Cursor::new(
+            Rect::new(
+                self.position.x + self.window_margin.left,
+                self.position.y + self.title_height + self.window_margin.top,
+                self.size.x - self.window_margin.left - self.window_margin.right,
+                self.size.y
+                    - self.title_height
+                    - self.window_margin.top
+                    - self.window_margin.bottom,
+            ),
+            self.margin,
+        );
+    }
+
     pub fn top_level(&self) -> bool {
         self.parent.is_none()
     }
@@ -620,7 +639,7 @@ impl InputHandler for Ui {
 }
 
 impl Ui {
-    pub fn new(ctx: &mut miniquad::Context) -> Ui {
+    pub fn new(ctx: &mut miniquad::Context, screen_width: f32, screen_height: f32) -> Ui {
         let atlas = Rc::new(RefCell::new(Atlas::new(ctx, miniquad::FilterMode::Nearest)));
         let mut font = crate::text::FontInternal::load_from_bytes(
             atlas.clone(),
@@ -650,12 +669,7 @@ impl Ui {
                     0,
                     None,
                     Vec2::new(0., 0.),
-                    // this is not going to be used anywhere but for clipping out
-                    // child window.
-                    // Scissor test is not going to be used by the root window size,
-                    // so this is fine to use weird hardcoded consts here.
-                    // mostly
-                    Vec2::new(10000., 10000.),
+                    Vec2::new(screen_width, screen_height),
                     0.0,
                     RectOffset::new(0.0, 0.0, 0.0, 0.0),
                     0.0,
@@ -679,7 +693,7 @@ impl Ui {
             storage_any: AnyStorage::default(),
             atlas,
             clipboard_selection: String::new(),
-            clipboard: Box::new(crate::ui::clipboard::LocalClipboard::new()),
+            clipboard: Box::new(ui_context::ClipboardObject),
             time: 0.0,
             key_repeat: key_repeat::KeyRepeat::new(),
             last_item_clicked: false,
@@ -943,10 +957,6 @@ impl Ui {
         )
     }
 
-    pub fn set_clipboard_object<T: crate::ui::ClipboardObject + 'static>(&mut self, clipboard: T) {
-        self.clipboard = Box::new(clipboard);
-    }
-
     pub fn is_mouse_captured(&self) -> bool {
         self.input.cursor_grabbed
     }
@@ -1029,6 +1039,11 @@ impl Ui {
     }
 
     pub fn new_frame(&mut self, delta: f32) {
+        self.root_window.resize(crate::math::vec2(
+            crate::window::screen_width(),
+            crate::window::screen_height(),
+        ));
+
         self.frame += 1;
         self.time += delta;
 
@@ -1177,10 +1192,12 @@ pub(crate) mod ui_context {
     }
 
     impl UiContext {
-        pub(crate) fn new(ctx: &mut miniquad::Context) -> UiContext {
-            let mut ui = megaui::Ui::new(ctx);
-
-            ui.set_clipboard_object(ClipboardObject);
+        pub(crate) fn new(
+            ctx: &mut miniquad::Context,
+            screen_width: f32,
+            screen_height: f32,
+        ) -> UiContext {
+            let ui = megaui::Ui::new(ctx, screen_width, screen_height);
 
             UiContext {
                 ui: Rc::new(RefCell::new(ui)),
